← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~trb143/openlp/servicing2 into lp:openlp

 

Tim Bentley has proposed merging lp:~trb143/openlp/servicing2 into lp:openlp.

Requested reviews:
    openlp.org Core (openlp-core)

It's big.
Includes Martins changes - followed by changes to get things working
Highlights of this merge.
- New SlideController with plugable toolbars
- New Live toolbar for Images with working timer loop.
- Martin's changes to MediamanagerItem
- Removal of the need to use listitemswithpreview.
- Removal of duplicate methods.

Various other bug fixes.

Test run all plugins and add display situations.
Tested no gsm installed! Hummmm.
-- 
https://code.launchpad.net/~trb143/openlp/servicing2/+merge/8210
Your team openlp.org Core is subscribed to branch lp:openlp.
=== modified file 'cnvdb.py'
--- cnvdb.py	2009-06-25 19:42:22 +0000
+++ cnvdb.py	2009-07-02 19:10:14 +0000
@@ -30,6 +30,8 @@
         infile = codecs.open(inname, 'r', encoding='iso-8859-1')
         writefile = codecs.open(outname, 'w', encoding='utf-8')
         for line in infile:
+            #replace the quotes with quotes
+            line, replace("''", "'")
             writefile.write(line)
         infile.close()
         writefile.close()

=== modified file 'openlp/core/lib/listwithpreviews.py'
--- openlp/core/lib/listwithpreviews.py	2009-06-23 20:59:38 +0000
+++ openlp/core/lib/listwithpreviews.py	2009-06-30 20:35:53 +0000
@@ -35,14 +35,18 @@
         self.items = []
         self.rowheight = 50
         self.maximagewidth = self.rowheight * 16 / 9.0;
-        if new_preview_function is not None:
-            self.make_preview=new_preview_function
-        else:
-            self.make_preview=self.preview_function
+        self.preview_function = new_preview_function
         
-    def preview_function(self, filename):
+    def make_preview(self, filename):
         if os.path.exists(filename):
-            preview = QtGui.QImage(filename)
+            if self.preview_function is not None:
+                preview=self.preview_function(filename)
+            else:
+                preview = QtGui.QImage(filename)
+        else:
+            preview = None
+            
+        if preview is not None:
             w = self.maximagewidth;
             h = self.rowheight
             preview = preview.scaled(w, h, QtCore.Qt.KeepAspectRatio, QtCore.Qt.SmoothTransformation)

=== modified file 'openlp/core/lib/mediamanageritem.py'
--- openlp/core/lib/mediamanageritem.py	2009-06-29 05:07:32 +0000
+++ openlp/core/lib/mediamanageritem.py	2009-07-04 05:52:30 +0000
@@ -23,14 +23,38 @@
 from PyQt4 import QtCore, QtGui
 
 from openlp.core.lib.toolbar import *
-from openlp.core.lib import translate
-from listwithpreviews import ListWithPreviews
+from openlp.core.lib import translate, contextMenuAction, contextMenuSeparator
 from serviceitem import ServiceItem
 
 class MediaManagerItem(QtGui.QWidget):
     """
     MediaManagerItem is a helper widget for plugins.
+
+    None of the following *need* to be used, feel free to override
+    them cmopletely in your plugin's implementation.  Alternatively, call them from your
+    plugin before or after you've done etra things that you need to.
+
+    The plugin will be assigned an icon called u':/media/media_' + 'self.ShortPluginName + u'image.png'
+     which needs to be available in the main resources in order for them to work, you need to have setup
+
+     self.TranslationContext
+     self.PluginTextShort # eg 'Image' for the image plugin
+     self.ConfigSection - where the items in the media manager are stored
+       this could potentially be self.PluginTextShort.lower()
+
+     self.OnNewPrompt=u'Select Image(s)'
+     self.OnNewFileMasks=u'Images (*.jpg *jpeg *.gif *.png *.bmp)'
+       assumes that the new action is to load a file. If not, override onnew
+
+     self.ListViewWithDnD_class - there is a base list class with DnD assigned to it (openlp.core.lib.BaseListWithDnD())
+     each plugin needs to inherit a class from this and pass that *class* (not an instance) to here
+     via the ListViewWithDnD_class member
+
+     self.PreviewFunction - a function which returns a QImage to represent the item (a preview usually)
+        - no scaling required - that's done later
+        If this fn is not defined, a default will be used (treat the filename as an image)
     """
+
     global log
     log = logging.getLogger(u'MediaManagerItem')
     log.info(u'Media Item loaded')
@@ -84,61 +108,6 @@
         """
         self.Toolbar.addSeparator()
 
-    def contextMenuSeparator(self, base):
-        action = QtGui.QAction(u'', base)
-        action.setSeparator(True)
-        return action
-
-    def contextMenuAction(self, base, icon, text, slot):
-        """
-        Utility method to help build context menus for plugins
-        """
-        if type(icon) is QtGui.QIcon:
-            ButtonIcon = icon
-        elif type(icon) is types.StringType or type(icon) is types.UnicodeType:
-            ButtonIcon = QtGui.QIcon()
-            if icon.startswith(u':/'):
-                ButtonIcon.addPixmap(QtGui.QPixmap(icon), QtGui.QIcon.Normal,
-                    QtGui.QIcon.Off)
-            else:
-                ButtonIcon.addPixmap(QtGui.QPixmap.fromImage(QtGui.QImage(icon)),
-                    QtGui.QIcon.Normal, QtGui.QIcon.Off)
-
-        action = QtGui.QAction(text, base)
-        action .setIcon(ButtonIcon)
-        QtCore.QObject.connect(action, QtCore.SIGNAL(u'triggered()'), slot)
-        return action
-
-    ###########################################################################
-    ### None of the following *need* to be used, feel free to override
-    ### them cmopletely in your plugin's implementation.  Alternatively, call them from your
-    ### plugin before or after you've done etra things that you need to.
-    ### in order for them to work, you need to have setup
-    # self.TranslationContext
-    # self.PluginTextShort # eg "Image" for the image plugin
-    # self.ConfigSection - where the items in the media manager are stored
-    #   this could potentially be self.PluginTextShort.lower()
-    # self.IconPath=u'images/images' - allows specific icons to be used
-    # self.hasFileIcon - Is the file Icon required
-    # self.hasEditIcon - Is the edit Icon required
-    # self.hasNewIcon - Is the new Icon required
-    #
-    # self.OnNewPrompt=u'Select Image(s)'
-    # self.OnNewFileMasks=u'Images (*.jpg *jpeg *.gif *.png *.bmp)'
-    #   assumes that the new action is to load a file. If not, override onnew
-    # self.ListViewWithDnD_class - there is a base list class with DnD assigned to it (openlp.core.lib.BaseListWithDnD())
-    #    each plugin needs to inherit a class from this and pass that *class* (not an instance) to here
-    #    via the ListViewWithDnD_class member
-    # The assumption is that given that at least two plugins are of the form
-    # "text with an icon" then all this will help
-    # even for plugins of another sort, the setup of the right-click menu, common toolbar
-    # will help to keep things consistent and ease the creation of new plugins
-
-    # also a set of completely consistent action anesm then exist
-    # (onPreviewClick() is always called that, rather than having the
-    # name of the plugin added in as well... I regard that as a
-    # feature, I guess others might differ!)
-
     def setupUi(self):
         # Add a toolbar
         self.addToolbar()
@@ -168,7 +137,7 @@
             u':'+self.IconPath+ u'_delete.png', self.onDeleteClick, self.PluginTextShort+u'DeleteItem')
         ## Separator Line ##
         self.addToolbarSeparator()
-        ## Preview  Button ##
+        ## Preview ##
         self.addToolbarButton(
             translate(self.TranslationContext, u'Preview '+self.PluginTextShort),
             translate(self.TranslationContext, u'Preview the selected item'),
@@ -178,7 +147,7 @@
             translate(self.TranslationContext, u'Go Live'),
             translate(self.TranslationContext, u'Send the selected item live'),
             u':/system/system_live.png', self.onLiveClick, u'LiveItem')
-        ## Add  Button ##
+        ## Add to service Button ##
         self.addToolbarButton(
             translate(self.TranslationContext, u'Add '+self.PluginTextShort+u' To Service'),
             translate(self.TranslationContext, u'Add the selected item(s) to the service'),
@@ -199,26 +168,29 @@
         #define and add the context menu
         self.ListView.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
         if self.hasEditIcon:
-            self.ListView.addAction(self.contextMenuAction(self.ListView,
+            self.ListView.addAction(contextMenuAction(self.ListView,
                 ':' +self.IconPath+u'_new.png',
                 translate(self.TranslationContext, u'&Edit '+self.PluginTextShort),
                 self.onEditClick))
             self.ListView.addAction(self.contextMenuSeparator(self.SongListWidget))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_preview.png',
             translate(self.TranslationContext, u'&Preview '+self.PluginTextShort),
             self.onPreviewClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_live.png',
             translate(self.TranslationContext, u'&Show Live'),
             self.onLiveClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_add.png',
             translate(self.TranslationContext, u'&Add to Service'),
             self.onAddClick))
         QtCore.QObject.connect(self.ListView,
            QtCore.SIGNAL(u'doubleClicked(QModelIndex)'), self.onPreviewClick)
 
+    def initialise(self):
+        pass
+
     def addHeaderBar(self):
         pass
 
@@ -232,12 +204,15 @@
             self.loadList(files)
             dir, filename = os.path.split(unicode(files[0]))
             self.parent.config.set_last_dir(dir)
-            #self.parent.config.set_list(self.ConfigSection, self.ListData.getFileList())
+            self.parent.config.set_list(self.ConfigSection, self.getFileList())
 
     def getFileList(self):
         count = 0
-        while  count < len(self.ListView):
-            filelist = [set.ListView.item(count).text()]
+        filelist = []
+        while  count < self.ListView.count():
+            bitem =  self.ListView.item(count)
+            filename = unicode((bitem.data(QtCore.Qt.UserRole)).toString())
+            filelist.append(filename)
             count += 1
         return filelist
 
@@ -257,7 +232,7 @@
         raise NotImplementedError(u'MediaManagerItem.generateSlideData needs to be defined by the plugin')
 
     def onPreviewClick(self):
-        log.debug(self.PluginTextShort+u'Preview Requested')
+        log.debug(self.PluginTextShort+u' Preview Requested')
         service_item = ServiceItem(self.parent)
         service_item.addIcon(u':/media/media_'+self.PluginTextShort.lower()+u'.png')
         self.generateSlideData(service_item)

=== modified file 'openlp/core/lib/rendermanager.py'
--- openlp/core/lib/rendermanager.py	2009-06-20 11:23:34 +0000
+++ openlp/core/lib/rendermanager.py	2009-07-02 19:04:50 +0000
@@ -155,8 +155,12 @@
 
     def calculate_default(self, screen):
         log.debug(u'calculate default %s' , screen)
-        self.width = screen.width()
-        self.height = screen.height()
+        if self.current_display == 0:
+            self.width = 1024
+            self.height = 768
+        else:
+            self.width = screen.width()
+            self.height = screen.height()
         log.debug(u'calculate default %d,%d' , self.width, self.height)
         # 90% is start of footer
         self.footer_start = int(self.height * 0.90)

=== modified file 'openlp/core/resources.py'
--- openlp/core/resources.py	2009-05-03 15:35:34 +0000
+++ openlp/core/resources.py	2009-07-03 19:08:21 +0000
@@ -2,8 +2,8 @@
 
 # Resource object code
 #
-# Created: Sun May 3 17:32:20 2009
-#      by: The Resource Compiler for PyQt (Qt v4.4.3)
+# Created: Fri Jul 3 19:41:53 2009
+#      by: The Resource Compiler for PyQt (Qt v4.5.0)
 #
 # WARNING! All changes made in this file will be lost!
 
@@ -316,6 +316,69 @@
 \x18\x56\x6a\x9d\x81\x33\x40\x02\x7c\xfb\x53\xca\xd4\x39\x03\xa8\
 \x5f\xd3\x56\x89\xec\x63\x12\x58\x4f\x00\x00\x00\x00\x49\x45\x4e\
 \x44\xae\x42\x60\x82\
+\x00\x00\x03\xcf\
+\x89\
+\x50\x4e\x47\x0d\x0a\x1a\x0a\x00\x00\x00\x0d\x49\x48\x44\x52\x00\
+\x00\x00\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xff\x61\
+\x00\x00\x00\x04\x73\x42\x49\x54\x08\x08\x08\x08\x7c\x08\x64\x88\
+\x00\x00\x00\x09\x70\x48\x59\x73\x00\x00\x01\xbb\x00\x00\x01\xbb\
+\x01\x3a\xec\xe3\xe2\x00\x00\x00\x19\x74\x45\x58\x74\x53\x6f\x66\
+\x74\x77\x61\x72\x65\x00\x77\x77\x77\x2e\x69\x6e\x6b\x73\x63\x61\
+\x70\x65\x2e\x6f\x72\x67\x9b\xee\x3c\x1a\x00\x00\x03\x4c\x49\x44\
+\x41\x54\x78\xda\x75\x53\x4d\x48\x5b\x69\x14\x3d\xdf\xcb\x33\xe6\
+\x47\x13\x4d\x34\x71\x14\x89\x12\xa5\xa9\x05\xed\xc6\x38\x95\x31\
+\xa2\x03\xaf\x2a\x43\x70\x53\xb5\x60\x53\x5a\x90\xb6\x48\x97\xa9\
+\xa5\xed\xa2\x5d\x76\x31\x1d\x98\x42\x5b\xc6\xc5\xd0\x01\x45\xe3\
+\x60\x19\x28\x48\xa3\xcc\x80\x53\xc4\x2e\x52\xa5\xf5\x17\x34\xd1\
+\x1a\x11\x6d\xcc\x7f\x62\x34\x3f\xaf\x97\xb7\x90\x76\xd1\x03\x1f\
+\xef\x2d\xbe\x7b\xee\x3d\xe7\x9e\x8f\x89\xa2\x88\xef\xa1\xb9\xb9\
+\xd9\x30\x37\x37\x77\x80\xaf\x30\x30\x30\xf0\x50\xad\x56\xff\x18\
+\x89\x44\xe2\x54\x7b\xfb\x1b\x82\xe9\xe9\x69\xb9\xdb\xed\x9e\x09\
+\x04\x02\xe7\x73\xb9\x5c\x81\xc1\x60\x60\xf4\xcd\x06\x83\xc1\x50\
+\x32\x99\x74\x8d\x8f\x8f\x0f\xfe\x31\x3c\x9c\xfc\xa9\xa9\x69\xa1\
+\x5d\x10\x2e\xda\x6c\xb6\x5f\x4f\x09\xba\xbb\xbb\x7f\x29\x2e\x2e\
+\x76\x59\xad\x56\xa5\x56\xa3\x11\xb7\xb7\xb7\x73\xd1\x48\x04\x2a\
+\xb5\x1a\x96\x33\x16\xae\xc5\x66\x63\x4f\x7e\x7b\xf2\xf9\x72\x6f\
+\x6f\x49\x95\xc9\xc4\x9c\x77\xee\xee\xce\xfc\x3b\xf3\xa7\x44\x30\
+\x38\x38\x68\xdd\xd9\xd9\x99\x7f\x70\xef\x3e\x7b\xfb\xf6\xff\xac\
+\x51\xa7\x93\xe5\xab\x54\xd0\x68\x34\x08\x85\x42\x88\x46\xa3\x58\
+\x5b\x5f\xcf\x5c\xee\xef\xe7\x7d\x5e\x9f\x38\x39\x39\x39\x27\x42\
+\x1c\x1d\x1b\x1b\x7b\x26\x11\x38\x1c\x8e\xe8\xad\x1b\x37\x0b\xbd\
+\x9b\x1b\x62\x43\x7d\x3d\x2b\xcc\x64\xa0\x2a\x2f\xc7\x29\x18\xc3\
+\xc7\xa5\x25\x2c\x2e\x2e\xe6\x7e\x16\x04\x6e\x6f\x6f\x6f\xa5\xa3\
+\xa3\xe3\x1c\x08\x5c\x5b\x5b\xdb\xa3\x6c\x36\x5b\x18\x09\x05\xd3\
+\x17\x05\x81\x29\x94\x4a\x28\x0c\x06\xc4\xd6\xd6\xc0\xc9\x64\xd2\
+\x09\xd2\x14\x0a\x85\x02\x8e\x2b\x57\xb8\xbf\x5e\xbe\x3c\x69\xb2\
+\x36\xd5\xb5\xb7\xb7\x9f\x07\x41\xd6\xda\xda\x3a\xec\xe8\x77\xe8\
+\xaa\xaa\x4c\x32\x9e\xe7\x11\x0d\x06\x91\x4f\xba\x63\x2b\x2b\xd0\
+\x9a\xcd\xd8\x3f\x38\x40\x98\xbc\x38\x4a\xa5\xb0\xfd\xe9\x13\xaa\
+\xab\xab\xd9\x1b\xb7\x9b\xf5\xf5\xf5\x71\xf4\xff\x9a\x0f\x87\xc3\
+\xe5\x99\x6c\x46\x34\x1a\x8d\x2c\x1e\x8f\xa3\x98\x74\x2b\xa9\x5b\
+\xea\xec\x59\x3c\xbf\x7a\x15\x3a\xbb\x1d\x3b\x7e\x3f\xf4\x7a\x3d\
+\xe4\x72\x39\x68\x43\x5c\x2c\x16\x83\x4a\xa1\xba\x44\x0d\x23\x3c\
+\x99\x24\x26\x12\x71\x70\x1c\x27\x99\x96\x21\xfd\x7c\x5e\x1e\xd6\
+\x77\x77\x91\x28\x2b\x43\x1e\x91\xf6\xf4\xf4\xa0\xb4\xb4\x54\x92\
+\x91\x4e\xa7\xe1\xf1\x78\xf0\xea\x9f\x57\x45\x95\x95\x95\x39\x2e\
+\x95\x4a\xed\x52\x28\xd8\x21\x8d\xce\x88\x44\x9e\x9f\x2f\x91\x95\
+\x57\x54\x20\xa5\xd3\xa1\xb3\xb3\x13\x35\x35\x35\x98\x9a\x9a\x42\
+\x22\x91\x00\x65\x03\xe4\x1b\x2c\x16\x0b\xb3\xdb\xed\x15\xdc\xe1\
+\xe1\xe1\x7f\x89\x44\x12\xef\x17\x16\x4e\x64\x64\xd8\xf1\xf1\xb1\
+\x44\xb0\xb5\xb5\x85\x92\x92\x12\xa9\xb3\x92\x8c\xf5\x7a\xbd\x18\
+\x1a\x1a\xc2\xc8\xc8\x08\x68\x74\x08\x82\x00\x6a\x7e\x81\xdf\xd8\
+\xd8\xb8\x49\x46\x5e\xa3\x20\xc9\x3f\x07\x02\xe0\x18\x83\xba\xa0\
+\x00\xd4\x4d\xba\x48\x64\xd2\x99\x9d\x9d\xc5\xf2\xf2\xb2\x94\x89\
+\x96\x96\x16\xc9\x13\x92\xab\xe7\x40\xf0\xfb\xfd\x8e\x78\x2c\x8e\
+\xdf\x9f\x3e\x15\x43\xe1\x70\x86\x0a\x60\x24\xfd\xfb\xfb\xfb\x92\
+\x27\x94\x15\x89\x8c\x02\x87\x89\x89\x09\x98\x4c\x26\xac\xd1\x9a\
+\xc9\x0f\xcf\x69\x94\xcd\x66\xf3\xe3\xeb\xd7\xae\x3b\xd3\x99\x34\
+\x4b\x1d\x1d\xe5\x6a\x6b\x6b\xb3\xf3\xef\xde\xf1\x34\x19\xa3\x9d\
+\xc3\xe7\xf3\xa1\xae\xae\x0e\x20\x50\x6e\xe0\x74\x3a\x41\x81\xba\
+\xf4\xcd\x63\xa2\xa2\x1f\xa8\xe0\x43\x91\xb6\x48\xaf\x50\x2a\xd8\
+\xe6\xe6\xa6\x34\x32\x49\x44\x57\x57\x17\xb4\x5a\x2d\x56\x57\x57\
+\x31\x3a\x3a\x0a\x2a\x7e\x41\x51\xbe\xf5\xdd\xe7\xdc\xd8\xd8\x58\
+\xd6\xd0\xd0\xd0\x49\x5e\xcc\x53\xc7\x7b\x00\x2e\x30\xc6\xf4\x74\
+\xdf\x03\xe0\x85\xcb\xe5\xfa\x1b\x84\x2f\x2c\xec\x8e\x1c\x74\xf5\
+\x29\x98\x00\x00\x00\x00\x49\x45\x4e\x44\xae\x42\x60\x82\
 \x00\x00\x02\x02\
 \x89\
 \x50\x4e\x47\x0d\x0a\x1a\x0a\x00\x00\x00\x0d\x49\x48\x44\x52\x00\
@@ -488,6 +551,54 @@
 \x8c\xb1\x50\x08\xd9\x60\x8c\x45\xd6\x9a\x08\x00\xfe\x06\x5b\x7b\
 \x9e\x53\x59\xbb\x17\xfa\x00\x00\x00\x00\x49\x45\x4e\x44\xae\x42\
 \x60\x82\
+\x00\x00\x02\xd2\
+\x89\
+\x50\x4e\x47\x0d\x0a\x1a\x0a\x00\x00\x00\x0d\x49\x48\x44\x52\x00\
+\x00\x00\x10\x00\x00\x00\x10\x08\x06\x00\x00\x00\x1f\xf3\xff\x61\
+\x00\x00\x00\x04\x73\x42\x49\x54\x08\x08\x08\x08\x7c\x08\x64\x88\
+\x00\x00\x00\x09\x70\x48\x59\x73\x00\x00\x01\xbb\x00\x00\x01\xbb\
+\x01\x3a\xec\xe3\xe2\x00\x00\x00\x19\x74\x45\x58\x74\x53\x6f\x66\
+\x74\x77\x61\x72\x65\x00\x77\x77\x77\x2e\x69\x6e\x6b\x73\x63\x61\
+\x70\x65\x2e\x6f\x72\x67\x9b\xee\x3c\x1a\x00\x00\x02\x4f\x49\x44\
+\x41\x54\x78\xda\xa5\x93\xcb\x4f\x13\x51\x14\x87\xbf\x3b\x33\x1d\
+\x5a\x5b\x0c\x19\xc0\x42\xa0\xe5\x61\x13\x17\x24\xa8\x71\x65\x8c\
+\x1b\x8d\x89\x3b\x57\xee\x64\xa7\x0b\x1f\x7b\x48\x7c\x9b\xe0\x42\
+\x4d\x8c\x8f\x3f\x42\x57\x2e\x5d\x68\x74\x61\x0a\xa8\x41\x40\x5d\
+\xb0\xd0\x50\x1e\xa2\xb5\x0d\x8f\x4e\xa1\x32\x33\x9d\xeb\x1d\x26\
+\x4e\x0a\x5b\x4f\x72\x72\xef\xe6\xfb\xf2\x3b\x77\xce\x08\x29\x25\
+\xff\x53\x06\xbb\x6a\x4e\x88\xc1\x55\x78\x66\xe6\x72\xc9\xa6\x5c\
+\x2e\x16\x4b\xa7\x75\xb7\x58\xac\x3b\xb3\xb3\xf6\x9e\x42\xe1\x6c\
+\x9f\x94\x9f\x77\x08\x76\xc3\xa5\x6c\x36\xdf\x79\x77\x34\xd5\x64\
+\x59\x08\xa1\x81\xa6\x21\x3d\x17\xa7\x62\x77\x2e\x0f\x0f\xe7\x11\
+\xe2\x58\xa3\x24\x18\x21\x82\x17\xbb\xbb\xf2\x3d\x37\x6e\xa6\xcc\
+\x8d\x2a\xb2\x5e\x07\xcf\xc3\x57\xa7\xef\xba\xd4\x7d\x1f\x69\xb5\
+\xb2\x74\xff\x5e\x35\xf3\x63\x39\x92\x68\xff\xe0\xb9\x8e\xf4\x58\
+\xcf\xed\x5b\x29\xbd\x5c\x42\x28\x48\x57\x2d\x2a\x15\x74\xd5\x86\
+\x82\x0d\x29\x91\xdf\xbf\x91\x1d\x19\x4e\x15\x3a\x3a\xc6\x02\x86\
+\x48\x60\x18\xcf\x7b\xaf\x5f\x4d\x6a\xf3\x0b\xe8\xbe\x4f\xdb\xb9\
+\x21\x5a\x87\x86\xd4\x3d\x10\x79\xb4\x9f\xbf\x40\xe7\xc5\x4b\x98\
+\x02\xdc\xc9\x49\x7a\xaf\x8d\x24\x03\x26\x7a\x83\x9a\xe7\x25\xaa\
+\x1f\x26\x68\x69\x69\x43\x98\x26\x38\x0e\x46\x26\x83\x75\xf9\x0a\
+\xc1\x88\x31\x75\x77\x0b\x73\xe8\xab\xab\x18\x2a\xd1\xc6\xfb\x89\
+\x6d\x26\x4a\xe0\x80\x60\xb3\x8a\x56\x59\x47\x2f\xfe\x62\x65\xf4\
+\x0e\xee\xc2\x3c\x46\x77\x46\xc1\x59\xdc\xc5\x05\xd6\x9f\x3c\x26\
+\xae\x44\xcd\x03\x03\x18\xba\xd8\x66\xa2\x04\x1e\x88\x95\xfc\x5b\
+\x9a\x8c\x66\xea\xc9\x24\x7a\x36\x1b\x3e\x22\x61\x49\xd7\x65\x63\
+\xfa\x13\xde\xf4\x14\x75\xdb\x66\x2d\x11\x32\x8d\x09\x90\x9b\x36\
+\xfc\x5c\xc6\x5d\x5f\xa3\xfd\xc1\x43\xcc\xbe\x7e\xfe\x7c\xfd\xb2\
+\xdd\x66\xff\x7e\xd2\x8f\x9e\xe2\x27\xe2\x88\x00\xd2\x43\x26\x4a\
+\x20\x61\xab\xa6\xb3\xa3\xb6\x14\xb8\x78\xfa\x24\xbe\xef\xd3\xf3\
+\xf2\x35\x9a\x69\x22\x01\x01\x54\xf4\x90\x89\xf6\x60\x4a\x88\x83\
+\xef\x62\x8c\x0f\x36\x93\xe8\xb2\x41\xdb\xd7\x1e\xda\x83\x4f\x0a\
+\xb8\x96\x05\x7a\x0c\x7e\x17\x59\x4a\xc1\x8c\x4d\xed\xb8\xcb\xd1\
+\xc3\x52\xce\x44\x8b\x14\x48\xde\x98\x8c\x1f\xd9\x4b\x22\x53\x21\
+\x8c\x2a\xc2\x53\x02\xbe\x84\xa5\x16\xc1\xc7\x35\x59\x3b\xe1\x84\
+\x70\xe3\x26\x46\x92\x57\x4a\x72\xc0\x57\x49\x52\x49\x62\xf1\x38\
+\xba\x61\x50\xf7\x3c\xca\x08\x26\x57\xca\xb5\x53\x0d\xf0\x6e\x41\
+\x24\x19\x87\x17\xea\x27\x4a\xc4\x2d\x4b\x0b\x66\xf7\x1d\x07\xaf\
+\x54\xaa\x1d\x2a\x97\xcf\x44\x70\xa3\xe0\x7f\xea\x2f\xb2\x2a\x1f\
+\x46\x55\x40\xa7\x1e\x00\x00\x00\x00\x49\x45\x4e\x44\xae\x42\x60\
+\x82\
 \x00\x00\x02\xf9\
 \x89\
 \x50\x4e\x47\x0d\x0a\x1a\x0a\x00\x00\x00\x0d\x49\x48\x44\x52\x00\
@@ -53362,13 +53473,17 @@
 \x00\x72\x00\x65\x00\x73\x00\x65\x00\x6e\x00\x74\x00\x61\x00\x74\x00\x69\x00\x6f\x00\x6e\x00\x5f\x00\x6c\x00\x6f\x00\x61\x00\x64\
 \x00\x2e\x00\x70\x00\x6e\x00\x67\
 \x00\x0f\
-\x0c\x7b\x40\x27\
+\x0c\xcb\x28\x47\
 \x00\x6d\
-\x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x76\x00\x65\x00\x72\x00\x73\x00\x65\x00\x2e\x00\x70\x00\x6e\x00\x67\
+\x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x62\x00\x69\x00\x62\x00\x6c\x00\x65\x00\x2e\x00\x70\x00\x6e\x00\x67\
 \x00\x0f\
 \x02\x3b\x21\xc7\
 \x00\x6d\
 \x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x69\x00\x6d\x00\x61\x00\x67\x00\x65\x00\x2e\x00\x70\x00\x6e\x00\x67\
+\x00\x0e\
+\x0b\x6a\xa6\xe7\
+\x00\x6d\
+\x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x74\x00\x69\x00\x6d\x00\x65\x00\x2e\x00\x70\x00\x6e\x00\x67\
 \x00\x10\
 \x05\xab\xe0\xa7\
 \x00\x6d\
@@ -53387,6 +53502,10 @@
 \x00\x6d\
 \x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x76\x00\x69\x00\x64\x00\x65\x00\x6f\x00\x2e\x00\x70\x00\x6e\x00\x67\
 \x00\x0e\
+\x0c\x3d\xa6\xe7\
+\x00\x6d\
+\x00\x65\x00\x64\x00\x69\x00\x61\x00\x5f\x00\x73\x00\x74\x00\x6f\x00\x70\x00\x2e\x00\x70\x00\x6e\x00\x67\
+\x00\x0e\
 \x06\xf2\xcf\x27\
 \x00\x73\
 \x00\x79\x00\x73\x00\x74\x00\x65\x00\x6d\x00\x5f\x00\x61\x00\x64\x00\x64\x00\x2e\x00\x70\x00\x6e\x00\x67\
@@ -53661,9 +53780,9 @@
 
 qt_resource_struct = "\
 \x00\x00\x00\x00\x00\x02\x00\x00\x00\x11\x00\x00\x00\x01\
-\x00\x00\x00\xa6\x00\x02\x00\x00\x00\x06\x00\x00\x00\x54\
-\x00\x00\x00\x38\x00\x02\x00\x00\x00\x04\x00\x00\x00\x50\
-\x00\x00\x01\x02\x00\x02\x00\x00\x00\x06\x00\x00\x00\x4a\
+\x00\x00\x00\xa6\x00\x02\x00\x00\x00\x06\x00\x00\x00\x56\
+\x00\x00\x00\x38\x00\x02\x00\x00\x00\x04\x00\x00\x00\x52\
+\x00\x00\x01\x02\x00\x02\x00\x00\x00\x08\x00\x00\x00\x4a\
 \x00\x00\x00\x5c\x00\x02\x00\x00\x00\x04\x00\x00\x00\x46\
 \x00\x00\x00\x4c\x00\x02\x00\x00\x00\x02\x00\x00\x00\x44\
 \x00\x00\x01\x12\x00\x02\x00\x00\x00\x02\x00\x00\x00\x42\
@@ -53678,78 +53797,80 @@
 \x00\x00\x00\xda\x00\x02\x00\x00\x00\x08\x00\x00\x00\x17\
 \x00\x00\x00\x24\x00\x02\x00\x00\x00\x04\x00\x00\x00\x13\
 \x00\x00\x00\xc6\x00\x02\x00\x00\x00\x01\x00\x00\x00\x12\
-\x00\x00\x06\x14\x00\x00\x00\x00\x00\x01\x00\x00\x4e\x96\
-\x00\x00\x0b\x16\x00\x00\x00\x00\x00\x01\x00\x0c\xd7\x8d\
-\x00\x00\x0b\x4a\x00\x00\x00\x00\x00\x01\x00\x0c\xda\xef\
-\x00\x00\x0b\x72\x00\x00\x00\x00\x00\x01\x00\x0c\xdd\x8d\
-\x00\x00\x0b\xa0\x00\x00\x00\x00\x00\x01\x00\x0c\xe0\xa1\
-\x00\x00\x05\x78\x00\x00\x00\x00\x00\x01\x00\x00\x44\x52\
-\x00\x00\x05\x9e\x00\x00\x00\x00\x00\x01\x00\x00\x46\x89\
-\x00\x00\x05\xea\x00\x00\x00\x00\x00\x01\x00\x00\x4b\xcb\
-\x00\x00\x05\x54\x00\x00\x00\x00\x00\x01\x00\x00\x42\x0b\
-\x00\x00\x04\xe4\x00\x00\x00\x00\x00\x01\x00\x00\x3a\xda\
-\x00\x00\x05\x08\x00\x00\x00\x00\x00\x01\x00\x00\x3d\x81\
-\x00\x00\x05\x2e\x00\x00\x00\x00\x00\x01\x00\x00\x3f\xf4\
-\x00\x00\x05\xc8\x00\x00\x00\x00\x00\x01\x00\x00\x49\x27\
+\x00\x00\x06\x58\x00\x00\x00\x00\x00\x01\x00\x00\x55\x3f\
+\x00\x00\x0b\x5a\x00\x00\x00\x00\x00\x01\x00\x0c\xde\x36\
+\x00\x00\x0b\x8e\x00\x00\x00\x00\x00\x01\x00\x0c\xe1\x98\
+\x00\x00\x0b\xb6\x00\x00\x00\x00\x00\x01\x00\x0c\xe4\x36\
+\x00\x00\x0b\xe4\x00\x00\x00\x00\x00\x01\x00\x0c\xe7\x4a\
+\x00\x00\x05\xbc\x00\x00\x00\x00\x00\x01\x00\x00\x4a\xfb\
+\x00\x00\x05\xe2\x00\x00\x00\x00\x00\x01\x00\x00\x4d\x32\
+\x00\x00\x06\x2e\x00\x00\x00\x00\x00\x01\x00\x00\x52\x74\
+\x00\x00\x05\x98\x00\x00\x00\x00\x00\x01\x00\x00\x48\xb4\
+\x00\x00\x05\x28\x00\x00\x00\x00\x00\x01\x00\x00\x41\x83\
+\x00\x00\x05\x4c\x00\x00\x00\x00\x00\x01\x00\x00\x44\x2a\
+\x00\x00\x05\x72\x00\x00\x00\x00\x00\x01\x00\x00\x46\x9d\
+\x00\x00\x06\x0c\x00\x00\x00\x00\x00\x01\x00\x00\x4f\xd0\
 \x00\x00\x01\x4c\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
 \x00\x00\x01\xb2\x00\x00\x00\x00\x00\x01\x00\x00\x05\xe6\
 \x00\x00\x01\x7e\x00\x00\x00\x00\x00\x01\x00\x00\x02\xfe\
-\x00\x00\x08\xa0\x00\x00\x00\x00\x00\x01\x00\x04\x89\xa2\
-\x00\x00\x09\x00\x00\x00\x00\x00\x00\x01\x00\x0a\x79\x20\
-\x00\x00\x08\xd0\x00\x00\x00\x00\x00\x01\x00\x04\xfa\xa6\
-\x00\x00\x09\x20\x00\x00\x00\x00\x00\x01\x00\x0b\xa7\x3a\
-\x00\x00\x08\x6a\x00\x00\x00\x00\x00\x01\x00\x04\x4e\xd1\
-\x00\x00\x08\x22\x00\x00\x00\x00\x00\x01\x00\x04\x4a\x1c\
-\x00\x00\x08\x48\x00\x00\x00\x00\x00\x01\x00\x04\x4c\xba\
-\x00\x00\x04\x9a\x00\x00\x00\x00\x00\x01\x00\x00\x34\x45\
-\x00\x00\x03\x4a\x00\x00\x00\x00\x00\x01\x00\x00\x1f\x4e\
-\x00\x00\x03\xde\x00\x00\x00\x00\x00\x01\x00\x00\x26\x32\
-\x00\x00\x04\x3a\x00\x00\x00\x00\x00\x01\x00\x00\x2b\x5c\
-\x00\x00\x03\x28\x00\x00\x00\x00\x00\x01\x00\x00\x1c\x51\
-\x00\x00\x03\x7e\x00\x00\x00\x00\x00\x01\x00\x00\x21\x1e\
-\x00\x00\x04\x66\x00\x00\x00\x00\x00\x01\x00\x00\x30\x68\
-\x00\x00\x04\xc0\x00\x00\x00\x00\x00\x01\x00\x00\x37\x27\
-\x00\x00\x04\x02\x00\x00\x00\x00\x00\x01\x00\x00\x28\xe6\
-\x00\x00\x03\xa8\x00\x00\x00\x00\x00\x01\x00\x00\x23\x82\
-\x00\x00\x06\x6c\x00\x00\x00\x00\x00\x01\x00\x02\xf2\x16\
-\x00\x00\x06\xd4\x00\x00\x00\x00\x00\x01\x00\x02\xfb\xa5\
-\x00\x00\x06\x8c\x00\x00\x00\x00\x00\x01\x00\x02\xf5\xf3\
-\x00\x00\x06\xb2\x00\x00\x00\x00\x00\x01\x00\x02\xf8\x6b\
-\x00\x00\x06\x46\x00\x00\x00\x00\x00\x01\x00\x02\xef\x78\
-\x00\x00\x0c\x50\x00\x00\x00\x00\x00\x01\x00\x0c\xed\x2b\
-\x00\x00\x0b\xe6\x00\x00\x00\x00\x00\x01\x00\x0c\xe5\x56\
-\x00\x00\x0c\x0a\x00\x00\x00\x00\x00\x01\x00\x0c\xe7\xe7\
-\x00\x00\x0c\x2c\x00\x00\x00\x00\x00\x01\x00\x0c\xe9\xfa\
-\x00\x00\x0b\xc4\x00\x00\x00\x00\x00\x01\x00\x0c\xe2\xb8\
-\x00\x00\x09\x7c\x00\x00\x00\x00\x00\x01\x00\x0c\xba\xc3\
-\x00\x00\x09\x56\x00\x00\x00\x00\x00\x01\x00\x0c\xb8\x25\
-\x00\x00\x0c\x9e\x00\x00\x00\x00\x00\x01\x00\x0c\xf1\xcf\
-\x00\x00\x0c\xc6\x00\x00\x00\x00\x00\x01\x00\x0c\xf4\x6d\
-\x00\x00\x0c\x7a\x00\x00\x00\x00\x00\x01\x00\x0c\xef\x2f\
+\x00\x00\x08\xe4\x00\x00\x00\x00\x00\x01\x00\x04\x90\x4b\
+\x00\x00\x09\x44\x00\x00\x00\x00\x00\x01\x00\x0a\x7f\xc9\
+\x00\x00\x09\x14\x00\x00\x00\x00\x00\x01\x00\x05\x01\x4f\
+\x00\x00\x09\x64\x00\x00\x00\x00\x00\x01\x00\x0b\xad\xe3\
+\x00\x00\x08\xae\x00\x00\x00\x00\x00\x01\x00\x04\x55\x7a\
+\x00\x00\x08\x66\x00\x00\x00\x00\x00\x01\x00\x04\x50\xc5\
+\x00\x00\x08\x8c\x00\x00\x00\x00\x00\x01\x00\x04\x53\x63\
+\x00\x00\x04\xde\x00\x00\x00\x00\x00\x01\x00\x00\x3a\xee\
+\x00\x00\x03\x8e\x00\x00\x00\x00\x00\x01\x00\x00\x25\xf7\
+\x00\x00\x04\x22\x00\x00\x00\x00\x00\x01\x00\x00\x2c\xdb\
+\x00\x00\x04\x7e\x00\x00\x00\x00\x00\x01\x00\x00\x32\x05\
+\x00\x00\x03\x6c\x00\x00\x00\x00\x00\x01\x00\x00\x22\xfa\
+\x00\x00\x03\xc2\x00\x00\x00\x00\x00\x01\x00\x00\x27\xc7\
+\x00\x00\x04\xaa\x00\x00\x00\x00\x00\x01\x00\x00\x37\x11\
+\x00\x00\x05\x04\x00\x00\x00\x00\x00\x01\x00\x00\x3d\xd0\
+\x00\x00\x04\x46\x00\x00\x00\x00\x00\x01\x00\x00\x2f\x8f\
+\x00\x00\x03\xec\x00\x00\x00\x00\x00\x01\x00\x00\x2a\x2b\
+\x00\x00\x06\xb0\x00\x00\x00\x00\x00\x01\x00\x02\xf8\xbf\
+\x00\x00\x07\x18\x00\x00\x00\x00\x00\x01\x00\x03\x02\x4e\
+\x00\x00\x06\xd0\x00\x00\x00\x00\x00\x01\x00\x02\xfc\x9c\
+\x00\x00\x06\xf6\x00\x00\x00\x00\x00\x01\x00\x02\xff\x14\
+\x00\x00\x06\x8a\x00\x00\x00\x00\x00\x01\x00\x02\xf6\x21\
+\x00\x00\x0c\x94\x00\x00\x00\x00\x00\x01\x00\x0c\xf3\xd4\
+\x00\x00\x0c\x2a\x00\x00\x00\x00\x00\x01\x00\x0c\xeb\xff\
+\x00\x00\x0c\x4e\x00\x00\x00\x00\x00\x01\x00\x0c\xee\x90\
+\x00\x00\x0c\x70\x00\x00\x00\x00\x00\x01\x00\x0c\xf0\xa3\
+\x00\x00\x0c\x08\x00\x00\x00\x00\x00\x01\x00\x0c\xe9\x61\
+\x00\x00\x09\xc0\x00\x00\x00\x00\x00\x01\x00\x0c\xc1\x6c\
+\x00\x00\x09\x9a\x00\x00\x00\x00\x00\x01\x00\x0c\xbe\xce\
+\x00\x00\x0c\xe2\x00\x00\x00\x00\x00\x01\x00\x0c\xf8\x78\
+\x00\x00\x0d\x0a\x00\x00\x00\x00\x00\x01\x00\x0c\xfb\x16\
+\x00\x00\x0c\xbe\x00\x00\x00\x00\x00\x01\x00\x0c\xf5\xd8\
 \x00\x00\x01\xde\x00\x00\x00\x00\x00\x01\x00\x00\x09\x05\
 \x00\x00\x02\x12\x00\x00\x00\x00\x00\x01\x00\x00\x0b\xa3\
-\x00\x00\x0a\x24\x00\x00\x00\x00\x00\x01\x00\x0c\xc6\xe1\
-\x00\x00\x0a\x48\x00\x00\x00\x00\x00\x01\x00\x0c\xc9\xdf\
-\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x01\x00\x0c\xc4\x43\
-\x00\x00\x09\x9e\x00\x00\x00\x00\x00\x01\x00\x0c\xbc\xda\
-\x00\x00\x09\xdc\x00\x00\x00\x00\x00\x01\x00\x0c\xc1\xc1\
-\x00\x00\x09\xbc\x00\x00\x00\x00\x00\x01\x00\x0c\xbf\x21\
+\x00\x00\x0a\x68\x00\x00\x00\x00\x00\x01\x00\x0c\xcd\x8a\
+\x00\x00\x0a\x8c\x00\x00\x00\x00\x00\x01\x00\x0c\xd0\x88\
+\x00\x00\x0a\x44\x00\x00\x00\x00\x00\x01\x00\x0c\xca\xec\
+\x00\x00\x09\xe2\x00\x00\x00\x00\x00\x01\x00\x0c\xc3\x83\
+\x00\x00\x0a\x20\x00\x00\x00\x00\x00\x01\x00\x0c\xc8\x6a\
+\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x01\x00\x0c\xc5\xca\
 \x00\x00\x02\x66\x00\x00\x00\x00\x00\x01\x00\x00\x10\x0c\
-\x00\x00\x02\xb0\x00\x00\x00\x00\x00\x01\x00\x00\x14\x2c\
-\x00\x00\x02\xe2\x00\x00\x00\x00\x00\x01\x00\x00\x16\x57\
+\x00\x00\x02\xd2\x00\x00\x00\x00\x00\x01\x00\x00\x17\xff\
+\x00\x00\x03\x04\x00\x00\x00\x00\x00\x01\x00\x00\x1a\x2a\
+\x00\x00\x02\xac\x00\x00\x00\x00\x00\x01\x00\x00\x15\xf9\
 \x00\x00\x02\x8a\x00\x00\x00\x00\x00\x01\x00\x00\x12\x26\
+\x00\x00\x03\x4a\x00\x00\x00\x00\x00\x01\x00\x00\x20\x24\
 \x00\x00\x02\x42\x00\x00\x00\x00\x00\x01\x00\x00\x0d\xba\
-\x00\x00\x03\x04\x00\x00\x00\x00\x00\x01\x00\x00\x18\xba\
-\x00\x00\x0a\x68\x00\x00\x00\x00\x00\x01\x00\x0c\xcc\x62\
-\x00\x00\x0a\xca\x00\x00\x00\x00\x00\x01\x00\x0c\xd2\xd8\
-\x00\x00\x0a\x9c\x00\x00\x00\x00\x00\x01\x00\x0c\xcf\xc4\
-\x00\x00\x0a\xf2\x00\x00\x00\x00\x00\x01\x00\x0c\xd5\x76\
-\x00\x00\x07\x8a\x00\x00\x00\x00\x00\x01\x00\x03\x37\xfb\
-\x00\x00\x07\x2a\x00\x00\x00\x00\x00\x01\x00\x03\x08\xbb\
-\x00\x00\x06\xfa\x00\x00\x00\x00\x00\x01\x00\x02\xfe\x27\
-\x00\x00\x07\x5a\x00\x00\x00\x00\x00\x01\x00\x03\x1d\xf0\
-\x00\x00\x07\xba\x00\x00\x00\x00\x00\x01\x00\x03\x3c\x18\
-\x00\x00\x07\xee\x00\x00\x00\x00\x00\x01\x00\x04\x04\xb1\
+\x00\x00\x03\x26\x00\x00\x00\x00\x00\x01\x00\x00\x1c\x8d\
+\x00\x00\x0a\xac\x00\x00\x00\x00\x00\x01\x00\x0c\xd3\x0b\
+\x00\x00\x0b\x0e\x00\x00\x00\x00\x00\x01\x00\x0c\xd9\x81\
+\x00\x00\x0a\xe0\x00\x00\x00\x00\x00\x01\x00\x0c\xd6\x6d\
+\x00\x00\x0b\x36\x00\x00\x00\x00\x00\x01\x00\x0c\xdc\x1f\
+\x00\x00\x07\xce\x00\x00\x00\x00\x00\x01\x00\x03\x3e\xa4\
+\x00\x00\x07\x6e\x00\x00\x00\x00\x00\x01\x00\x03\x0f\x64\
+\x00\x00\x07\x3e\x00\x00\x00\x00\x00\x01\x00\x03\x04\xd0\
+\x00\x00\x07\x9e\x00\x00\x00\x00\x00\x01\x00\x03\x24\x99\
+\x00\x00\x07\xfe\x00\x00\x00\x00\x00\x01\x00\x03\x42\xc1\
+\x00\x00\x08\x32\x00\x00\x00\x00\x00\x01\x00\x04\x0b\x5a\
 "
 
 def qInitResources():

=== modified file 'openlp/core/ui/__init__.py'
--- openlp/core/ui/__init__.py	2009-06-29 05:07:32 +0000
+++ openlp/core/ui/__init__.py	2009-07-03 19:08:21 +0000
@@ -17,7 +17,7 @@
 this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 Place, Suite 330, Boston, MA 02111-1307 USA
 """
-from slidecontroller import BaseToolbar
+from slidecontroller import MasterToolbar
 from slidecontrollermanager import SlideControllerManager
 from maindisplay import MainDisplay
 from amendthemeform import AmendThemeForm
@@ -33,5 +33,5 @@
 from thememanager import ThemeManager
 from mainwindow import MainWindow
 
-__all__ = ['SplashScreen', 'AboutForm', 'SettingsForm', 'BaseToolbar'
+__all__ = ['SplashScreen', 'AboutForm', 'SettingsForm', 'MasterToolbar'
            'MainWindow', 'MainDisplay',  'SlideController', 'ServiceManager', 'ThemeManager', 'AmendThemeForm']

=== modified file 'openlp/core/ui/maindisplay.py'
--- openlp/core/ui/maindisplay.py	2009-06-17 05:11:16 +0000
+++ openlp/core/ui/maindisplay.py	2009-07-03 19:08:21 +0000
@@ -78,7 +78,7 @@
     def blankDisplay(self):
         if not self.displayBlank:
             self.displayBlank = True
-            self.display.setPixmap(self.blankFrame)
+            self.display.setPixmap(QtGui.QPixmap.fromImage(self.blankFrame))
         else:
             self.displayBlank = False
             self.frameView(self.frame)

=== modified file 'openlp/core/ui/mainwindow.py'
--- openlp/core/ui/mainwindow.py	2009-06-29 05:07:32 +0000
+++ openlp/core/ui/mainwindow.py	2009-07-03 19:08:21 +0000
@@ -205,7 +205,7 @@
         self.MediaManagerDock.setWindowIcon(icon)
         self.MediaManagerDock.setFloating(False)
         self.MediaManagerDock.setObjectName(u'MediaManagerDock')
-        self.MediaManagerDock.setMinimumWidth(250)
+        self.MediaManagerDock.setMinimumWidth(300)
         self.MediaManagerContents = QtGui.QWidget()
         self.MediaManagerContents.setObjectName(u'MediaManagerContents')
         self.MediaManagerLayout = QtGui.QHBoxLayout(self.MediaManagerContents)
@@ -227,7 +227,7 @@
         self.ServiceManagerDock.setFeatures(
             QtGui.QDockWidget.AllDockWidgetFeatures)
         self.ServiceManagerDock.setObjectName(u'ServiceManagerDock')
-        self.ServiceManagerDock.setMinimumWidth(250)
+        self.ServiceManagerDock.setMinimumWidth(300)
         self.ServiceManagerContents = ServiceManager(self)
         self.ServiceManagerDock.setWidget(self.ServiceManagerContents)
         self.mainWindow.addDockWidget(

=== modified file 'openlp/core/ui/slidecontroller.py'
--- openlp/core/ui/slidecontroller.py	2009-06-29 05:07:32 +0000
+++ openlp/core/ui/slidecontroller.py	2009-07-03 20:32:33 +0000
@@ -21,100 +21,28 @@
 import os
 
 from PyQt4 import QtCore, QtGui
-from openlp.core.lib import OpenLPToolbar, translate
-
-class SlideData(QtCore.QAbstractListModel):
-    """
-    List of frames to be displayed on the list and the main display.
-    """
-    global log
-    log = logging.getLogger(u'SlideData')
-
-    def __init__(self):
-        QtCore.QAbstractListModel.__init__(self)
-        self.items = []
-        self.rowheight = 50
-        self.maximagewidth = self.rowheight * 16 / 9.0;
-        log.info(u'Starting')
-
-    def clear(self):
-        self.items = []
-
-    def columnCount(self, parent):
-        return 1
-
-    def rowCount(self, parent=None):
-        return len(self.items)
-
-    def insertRow(self, row, frame, framenumber):
-        self.beginInsertRows(QtCore.QModelIndex(), row, row)
-        log.info(u'insert row %d' % row)
-        # create a preview image
-        frame1 = frame.scaled(QtCore.QSize(280, 210), QtCore.Qt.KeepAspectRatio,
-            QtCore.Qt.SmoothTransformation)
-        self.items.insert(row, (frame1, framenumber))
-        log.info(u'Item loaded')
-        self.endInsertRows()
-
-    def removeRow(self, row):
-        self.beginRemoveRows(QtCore.QModelIndex(), row, row)
-        self.items.pop(row)
-        self.endRemoveRows()
-
-    def addRow(self, frame, framenumber):
-        self.insertRow(len(self.items), frame, framenumber)
-
-    def data(self, index, role):
-        row = index.row()
-        if row > len(self.items):
-            # if the last row is selected and deleted, we then get called with
-            # an empty row!
-            return QtCore.QVariant()
-        if role == QtCore.Qt.DecorationRole:
-            retval = self.items[row][0]
-        else:
-            retval = QtCore.QVariant()
-        if type(retval) is not type(QtCore.QVariant):
-            return QtCore.QVariant(retval)
-        else:
-            return retval
-
-    def __iter__(self):
-        for item in self.items:
-            yield item
-
-    def getValue(self, index):
-        row = index.row()
-        return self.items[row]
-
-    def getItem(self, row):
-        log.info(u'Get Item:%d -> %s' %(row, unicode(self.items)))
-        return self.items[row]
-
-    def getList(self):
-        filelist = [item[3] for item in self.items];
-        return filelist
-
-class SlideList(QtGui.QListView):
+from openlp.core.lib import OpenLPToolbar, translate, buildIcon
+
+class SlideList(QtGui.QTableWidget):
 
     def __init__(self,parent=None,name=None):
-        QtGui.QListView.__init__(self,parent.Controller)
+        QtGui.QTableWidget.__init__(self,parent.Controller)
         self.parent = parent
 
     def keyPressEvent(self, event):
         if type(event) == QtGui.QKeyEvent:
             #here accept the event and do something
             if event.key() == QtCore.Qt.Key_Up:
-                self.parent.onSlideSelectedPrevious()
+                self.parent.BaseToolbar.onSlideSelectedPrevious()
                 event.accept()
             elif event.key() == QtCore.Qt.Key_Down:
-                self.parent.onSlideSelectedNext()
+                self.parent.BaseToolbar.onSlideSelectedNext()
                 event.accept()
             elif event.key() == QtCore.Qt.Key_PageUp:
-                self.parent.onSlideSelectedFirst()
+                self.parent.BaseToolbar.onSlideSelectedFirst()
                 event.accept()
             elif event.key() == QtCore.Qt.Key_PageDown:
-                self.parent.onSlideSelectedLast()
+                self.parent.BaseToolbar.onSlideSelectedLast()
                 event.accept()
             event.ignore()
         else:
@@ -132,6 +60,7 @@
         """
         Set up the Slide Controller.
         """
+        self.toolbarList = {}
         QtGui.QWidget.__init__(self, parent.mainWindow)
         self.isLive = isLive
         self.parent = parent
@@ -145,7 +74,7 @@
         self.PanelLayout.setMargin(0)
         # Actual controller section
         self.Controller = QtGui.QWidget(self.Splitter)
-        self.Controller.setGeometry(QtCore.QRect(0, 0, 800, 536))
+        self.Controller.setGeometry(QtCore.QRect(0, 0, 100, 536))
         self.Controller.setSizePolicy(
             QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred,
             QtGui.QSizePolicy.Maximum))
@@ -153,21 +82,17 @@
         self.ControllerLayout.setSpacing(0)
         self.ControllerLayout.setMargin(0)
         # Controller list view
-        self.PreviewListView = SlideList(self)
-        self.PreviewListView.setUniformItemSizes(True)
-        self.PreviewListView.setIconSize(QtCore.QSize(250, 190))
-        self.PreviewListData = SlideData()
-        self.PreviewListView.isLive = self.isLive
-        if QtCore.QT_VERSION_STR > u'4.4.0':
-            self.PreviewListView.setFlow(1)
-            self.PreviewListView.setViewMode(1)
-        self.PreviewListView.setWrapping(False)
-        self.PreviewListView.setModel(self.PreviewListData)
-        self.PreviewListView.setSpacing(0)
-        self.PreviewListView.setObjectName(u'PreviewListView')
-        self.ControllerLayout.addWidget(self.PreviewListView)
+        self.PreviewListWidget = SlideList(self)
+        self.PreviewListWidget.setColumnCount(1)
+        self.PreviewListWidget.horizontalHeader().setVisible(False)
+        self.PreviewListWidget.verticalHeader().setVisible(False)
+        self.PreviewListWidget.setColumnWidth(1, self.Controller.width())
+        self.PreviewListWidget.isLive = self.isLive
+        self.PreviewListWidget.setObjectName(u'PreviewListWidget')
+        self.ControllerLayout.addWidget(self.PreviewListWidget)
         # Plugin the Base Toolbar class
-        self.BaseToolbar = BaseToolbar(self.isLive)
+        self.BaseToolbar = MasterToolbar(self.isLive)
+        self.registerToolbar(u'master', self.BaseToolbar)
         self.Toolbar = self.BaseToolbar.getToolbar()
         self.ControllerLayout.addWidget(self.Toolbar)
         sizeToolbarPolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed,
@@ -179,7 +104,7 @@
         self.Toolbar.setSizePolicy(sizeToolbarPolicy)
         # Screen preview area
         self.PreviewFrame = QtGui.QFrame(self.Splitter)
-        self.PreviewFrame.setGeometry(QtCore.QRect(0, 0, 250, 190))
+        self.PreviewFrame.setGeometry(QtCore.QRect(0, 0, 280, 190))
         self.PreviewFrame.setSizePolicy(QtGui.QSizePolicy(
             QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Minimum))
         self.PreviewFrame.setFrameShape(QtGui.QFrame.StyledPanel)
@@ -197,44 +122,83 @@
         sizePolicy.setHeightForWidth(
             self.SlidePreview.sizePolicy().hasHeightForWidth())
         self.SlidePreview.setSizePolicy(sizePolicy)
-        self.SlidePreview.setMinimumSize(QtCore.QSize(280, 210))
+        self.SlidePreview.setFixedSize(QtCore.QSize(250, 210))
         self.SlidePreview.setFrameShape(QtGui.QFrame.Box)
         self.SlidePreview.setFrameShadow(QtGui.QFrame.Plain)
         self.SlidePreview.setLineWidth(1)
         self.SlidePreview.setScaledContents(True)
         self.SlidePreview.setObjectName(u'SlidePreview')
         self.grid.addWidget(self.SlidePreview, 0, 0, 1, 1)
-        QtCore.QObject.connect(self.PreviewListView,
+        # Signals
+        QtCore.QObject.connect(self.PreviewListWidget,
             QtCore.SIGNAL(u'clicked(QModelIndex)'), self.BaseToolbar.onSlideSelected)
-        QtCore.QObject.connect(self.PreviewListView,
+        QtCore.QObject.connect(self.PreviewListWidget,
             QtCore.SIGNAL(u'activated(QModelIndex)'), self.BaseToolbar.onSlideSelected)
         # Add Late Arrivals
-        self.BaseToolbar.PreviewListView = self.PreviewListView
-        self.BaseToolbar.PreviewListData = self.PreviewListData
+        self.BaseToolbar.PreviewListWidget = self.PreviewListWidget
         self.BaseToolbar.SlidePreview = self.SlidePreview
         self.BaseToolbar.mainDisplay = self.parent.mainDisplay
 
+    def registerToolbar(self, handle,controller):
+        #store the handle name in lower case so no probems later
+        self.toolbarList[handle.lower()] = controller
+
+    def retrieveToolbar(self, handle):
+        """
+        Find the toolbar and return master if none present
+        Add extra information back into toolbar class
+        """
+        try:
+            toolbar =  self.toolbarList[handle.lower()]
+        except:
+            toolbar = self.toolbarList[u'master']
+        toolbar.PreviewListWidget = self.PreviewListWidget
+        toolbar.SlidePreview = self.SlidePreview
+        toolbar.mainDisplay = self.parent.mainDisplay
+        return toolbar
+
     def addServiceItem(self, item):
+        """
+        helper method to pass item to correct toolbar
+        """
+        self.BaseToolbar = self.retrieveToolbar(item.shortname)
+        self.ControllerLayout.removeWidget(self.Toolbar)
+        #remove the old toolbar
+        self.Toolbar.clear()
+        self.Toolbar = self.BaseToolbar.getToolbar()
+        self.ControllerLayout.addWidget(self.Toolbar)
         self.BaseToolbar.addServiceItem(item)
 
     def addServiceManagerItem(self, item, slideno):
+        """
+        helper method to pass item to correct toolbar
+        """
+        self.BaseToolbar = self.retrieveToolbar(item.shortname)
+        self.ControllerLayout.removeWidget(self.Toolbar)
+        #remove the old toolbar
+        self.Toolbar.clear()
+        self.Toolbar = self.BaseToolbar.getToolbar()
+        self.ControllerLayout.addWidget(self.Toolbar)
         self.BaseToolbar.addServiceManagerItem(item, slideno)
 
-class BaseToolbar(object):
-
+class MasterToolbar(QtCore.QObject):
+    """
+    Class from which all tollbars should extend
+    """
     def __init__(self, isLive):
         self.Toolbar = None
-        self.PreviewListView = QtGui.QListWidget()
-        self.PreviewListData = None
+        QtCore.QObject.__init__(self)
+        self.PreviewListWidget = QtGui.QListWidget()
         self.isLive = isLive
+
+    def getToolbar(self):
+        #define toolbar here as it needs to be redefined each time
+        #as the clear destroys it.
         self.defineToolbar()
-
-    def getToolbar(self):
         return self.Toolbar
 
     def defineToolbar(self):
         # Controller toolbar
-        #self.Toolbar = OpenLPToolbar(self.Controller)
         self.Toolbar = OpenLPToolbar(self)
         sizeToolbarPolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed,
             QtGui.QSizePolicy.Fixed)
@@ -249,11 +213,11 @@
                 u':/slides/slide_first.png',
                 translate(u'SlideController', u'Move to first'),
                 self.onSlideSelectedFirst)
-        self.Toolbar.addToolbarButton(u'Last Slide',
+        self.Toolbar.addToolbarButton(u'Previous Slide',
             u':/slides/slide_previous.png',
             translate(u'SlideController', u'Move to previous'),
             self.onSlideSelectedPrevious)
-        self.Toolbar.addToolbarButton(u'First Slide',
+        self.Toolbar.addToolbarButton(u'Next Slide',
             u':/slides/slide_next.png',
             translate(u'SlideController', u'Move to next'),
             self.onSlideSelectedNext)
@@ -272,56 +236,35 @@
         """
         Go to the first slide.
         """
-        row = self.PreviewListData.createIndex(0, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        self.PreviewListWidget.selectRow(0)
+        self.onSlideSelected()
 
     def onSlideSelectedNext(self):
         """
         Go to the next slide.
         """
-        indexes = self.PreviewListView.selectedIndexes()
-        rowNumber = 0
-        for index in indexes:
-            if index.row() == self.PreviewListData.rowCount() - 1:
-                rowNumber = 0
-            else:
-                rowNumber = index.row() + 1
-        row = self.PreviewListData.createIndex(rowNumber, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        row = self.PreviewListWidget.currentRow() + 1
+        if row == self.PreviewListWidget.rowCount():
+            row = 0
+        self.PreviewListWidget.selectRow(row)
+        self.onSlideSelected()
 
     def onSlideSelectedPrevious(self):
         """
         Go to the previous slide.
         """
-        indexes = self.PreviewListView.selectedIndexes()
-        rowNumber = 0
-        for index in indexes:
-            if index.row() == 0:
-                rowNumber = self.PreviewListData.rowCount() - 1
-            else:
-                rowNumber  = index.row() - 1
-        row = self.PreviewListData.createIndex(rowNumber, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        row = self.PreviewListWidget.currentRow() - 1
+        if row == -1:
+            row = self.PreviewListWidget.rowCount() - 1
+        self.PreviewListWidget.selectRow(row)
+        self.onSlideSelected()
 
     def onSlideSelectedLast(self):
         """
         Go to the last slide.
         """
-        row = self.PreviewListData.createIndex(
-            self.PreviewListData.rowCount() - 1, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        self.PreviewListWidget.selectRow(self.PreviewListWidget.rowCount() - 1)
+        self.onSlideSelected()
 
     def onBlankScreen(self):
         """
@@ -329,54 +272,56 @@
         """
         self.mainDisplay.blankDisplay()
 
-    def onSlideSelected(self, index):
+    def onSlideSelected(self):
         """
         Generate the preview when you click on a slide.
-        """
-        frame = self.PreviewListData.getValue(index)
-        self.previewFrame(frame)
-
-    def previewFrame(self, frame):
-        """
-        Generates a preview of the current slide.
-        """
-        self.SlidePreview.setPixmap(QtGui.QPixmap.fromImage(frame[0]))
-        if self.isLive:
-            no = frame[1]
-            LiveFrame = self.serviceitem.frames[no][u'image']
-            self.mainDisplay.frameView(LiveFrame)
-
-    def addServiceItem(self, serviceitem):
-        """
-        Loads a ServiceItem.
+        if this is the Live Controller also display on the screen
+        """
+        row = self.PreviewListWidget.currentRow()
+        if row > -1 and row < self.PreviewListWidget.rowCount():
+            label = self.PreviewListWidget.cellWidget(row, 0)
+            smallframe = label.pixmap()
+            frame = self.serviceitem.frames[row][u'image']
+            self.SlidePreview.setPixmap(smallframe)
+            if self.isLive:
+                self.mainDisplay.frameView(frame)
+
+    def addServiceItem(self, serviceitem, slideno = 1):
+        """
+        Loads a ServiceItem into the system from plugins
+        Display the first slide
         """
         log.debug(u'add Service Item')
-        self.serviceitem = serviceitem
-        self.serviceitem.render()
-        self.PreviewListData.clear()
-        framenumber = 0
-        for frame in self.serviceitem.frames:
-            self.PreviewListData.addRow(frame[u'image'], framenumber)
-            framenumber += 1
-        row = self.PreviewListData.createIndex(0, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        serviceitem.render()
+        self.addServiceManagerItem(serviceitem, 0)
 
     def addServiceManagerItem(self, serviceitem, slideno):
         """
-        Loads a ServiceManagerItem.
+        Loads a ServiceItem into the system from ServiceManager
+        Display the Slide Passed
         """
         log.debug(u'add Service Manager Item')
-        self.PreviewListData.clear()
+        self.PreviewListWidget.clear()
+        self.PreviewListWidget.setRowCount(0)
         self.serviceitem = serviceitem
         framenumber = 0
         for frame in self.serviceitem.frames:
-            self.PreviewListData.addRow(frame[u'image'], framenumber)
+            self.PreviewListWidget.setRowCount(self.PreviewListWidget.rowCount() + 1)
+            pixmap = QtGui.QPixmap.fromImage(frame[u'image'])
+            item = QtGui.QTableWidgetItem()
+            label = QtGui.QLabel()
+            label.setMargin(15)
+            label.setScaledContents(True)
+            width = 300
+            height = width * pixmap.height() / pixmap.width()
+            label.setPixmap(pixmap)
+            self.PreviewListWidget.setCellWidget(framenumber, 0,label)
+            self.PreviewListWidget.setItem( framenumber, 0, item)
+            self.PreviewListWidget.setRowHeight(framenumber, height)
+            self.PreviewListWidget.setColumnWidth(0, width)
             framenumber += 1
-        row = self.PreviewListData.createIndex(slideno, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        if slideno > self.PreviewListWidget.rowCount():
+            self.PreviewListWidget.selectRow(self.PreviewListWidget.rowCount())
+        else:
+            self.PreviewListWidget.selectRow(slideno)
+        self.onSlideSelected()

=== modified file 'openlp/core/ui/thememanager.py'
--- openlp/core/ui/thememanager.py	2009-06-29 05:07:32 +0000
+++ openlp/core/ui/thememanager.py	2009-07-02 19:04:50 +0000
@@ -177,7 +177,6 @@
         items = self.ThemeListView.selectedIndexes()
         if len(items) > 0:
             for item in items:
-                print item
                 data = self.themeData.getValue(item)
                 self.amendThemeForm.loadTheme(data[3])
             self.amendThemeForm.exec_()
@@ -222,7 +221,10 @@
         for root, dirs, files in os.walk(self.path):
             for name in files:
                 if name.endswith(u'.png'):
-                    self.themeData.addRow(os.path.join(self.path, name))
+                    #check to see file is in route directory
+                    theme =  os.path.join(self.path, name)
+                    if os.path.exists(theme):
+                        self.themeData.addRow(theme)
         self.parent.EventManager.post_event(Event(EventType.ThemeListChanged))
         self.parent.ServiceManagerContents.updateThemeList(self.getThemes())
         self.parent.settingsForm.ThemesTab.updateThemeList(self.getThemes())

=== modified file 'openlp/plugins/bibles/bibleplugin.py'
--- openlp/plugins/bibles/bibleplugin.py	2009-06-26 17:51:43 +0000
+++ openlp/plugins/bibles/bibleplugin.py	2009-07-03 20:32:33 +0000
@@ -37,7 +37,7 @@
         self.weight = -9
         # Create the plugin icon
         self.icon = QtGui.QIcon()
-        self.icon.addPixmap(QtGui.QPixmap(u':/media/media_verse.png'),
+        self.icon.addPixmap(QtGui.QPixmap(u':/media/media_bible.png'),
             QtGui.QIcon.Normal, QtGui.QIcon.Off)
         #Register the bible Manager
         self.biblemanager = BibleManager(self.config)

=== modified file 'openlp/plugins/bibles/lib/manager.py'
--- openlp/plugins/bibles/lib/manager.py	2009-06-20 19:11:17 +0000
+++ openlp/plugins/bibles/lib/manager.py	2009-07-03 20:32:33 +0000
@@ -245,7 +245,7 @@
                 log.debug(u'get_verse_text : new book')
                 for chapter in range(schapter, echapter+1):
                     search_results = self.bible_http_cache [bible].get_bible_chapter(bible, 0, bookname, chapter)
-                    if search_results.has_verse_list() :
+                    if search_results.has_verselist() :
                         ## We have found a book of the bible lets check to see if it was there.
                         ## By reusing the returned book name we get a correct book.
                         ## For example it is possible to request ac and get Acts back.

=== modified file 'openlp/plugins/bibles/lib/mediaitem.py'
--- openlp/plugins/bibles/lib/mediaitem.py	2009-06-29 05:07:32 +0000
+++ openlp/plugins/bibles/lib/mediaitem.py	2009-07-04 05:52:30 +0000
@@ -21,7 +21,7 @@
 
 from PyQt4 import QtCore, QtGui
 
-from openlp.core.lib import ServiceItem, MediaManagerItem, Receiver, translate
+from openlp.core.lib import ServiceItem, MediaManagerItem, Receiver, translate, contextMenuAction, contextMenuSeparator
 from openlp.plugins.bibles.forms import BibleImportForm
 
 class BibleList(QtGui.QListWidget):
@@ -215,13 +215,13 @@
             QtCore.SIGNAL(u'doubleClicked(QModelIndex)'), self.onPreviewClick)
         # Context Menus
         self.ListView.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, u':/system/system_preview.png',
             translate(u'BibleMediaItem',u'&Preview Verse'), self.onPreviewClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, u':/system/system_live.png',
             translate(u'BibleMediaItem',u'&Show Live'), self.onLiveClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, u':/system/system_add.png',
             translate(u'BibleMediaItem',u'&Add to Service'), self.onAddClick))
 

=== modified file 'openlp/plugins/custom/lib/mediaitem.py'
--- openlp/plugins/custom/lib/mediaitem.py	2009-06-27 19:55:55 +0000
+++ openlp/plugins/custom/lib/mediaitem.py	2009-07-04 05:52:30 +0000
@@ -21,7 +21,7 @@
 
 from PyQt4 import QtCore, QtGui
 
-from openlp.core.lib import MediaManagerItem,  SongXMLParser,  ServiceItem,  translate
+from openlp.core.lib import MediaManagerItem,  SongXMLParser,  ServiceItem,  translate, contextMenuAction, contextMenuSeparator
 
 class CustomList(QtGui.QListWidget):
 
@@ -114,17 +114,17 @@
             QtCore.SIGNAL(u'doubleClicked(QModelIndex)'), self.onCustomPreviewClick)
         #define and add the context menu
         self.ListView.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
-        self.ListView.addAction(self.contextMenuAction(self.ListView,
+        self.ListView.addAction(contextMenuAction(self.ListView,
             ':/custom/custom_edit.png', translate(u'CustomMediaItem', u'&Edit Custom'),
             self.onCustomEditClick))
-        self.ListView.addAction(self.contextMenuSeparator(self.ListView))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuSeparator(self.ListView))
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_preview.png',
             translate(u'CustomMediaItem',u'&Preview Custom'), self.onCustomPreviewClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_live.png',
             translate(u'CustomMediaItem',u'&Show Live'), self.onCustomLiveClick))
-        self.ListView.addAction(self.contextMenuAction(
+        self.ListView.addAction(contextMenuAction(
             self.ListView, ':/system/system_add.png',
             translate(u'CustomMediaItem',u'&Add to Service'), self.onCustomAddClick))
 

=== modified file 'openlp/plugins/images/imageplugin.py'
--- openlp/plugins/images/imageplugin.py	2009-06-27 15:33:03 +0000
+++ openlp/plugins/images/imageplugin.py	2009-07-03 20:32:33 +0000
@@ -22,7 +22,7 @@
 from PyQt4 import QtCore, QtGui
 
 from openlp.core.lib import Plugin, Event,  EventType
-from openlp.plugins.images.lib import ImageMediaItem
+from openlp.plugins.images.lib import ImageMediaItem,  ImageTab
 
 class ImagePlugin(Plugin):
     global log
@@ -40,6 +40,10 @@
         # passed with drag and drop messages
         self.dnd_id = u'Image'
 
+    def get_settings_tab(self):
+        self.ImageTab = ImageTab()
+        return self.ImageTab
+
     def get_media_manager_item(self):
         # Create the MediaManagerItem object
         self.media_item = ImageMediaItem(self, self.icon, u'Images')

=== modified file 'openlp/plugins/images/lib/__init__.py'
--- openlp/plugins/images/lib/__init__.py	2009-06-29 05:07:32 +0000
+++ openlp/plugins/images/lib/__init__.py	2009-07-03 20:32:33 +0000
@@ -19,3 +19,4 @@
 """
 from mediaitem import ImageMediaItem
 from imageslidecontroller import ImageToolbar
+from imagetab import ImageTab

=== modified file 'openlp/plugins/images/lib/imageslidecontroller.py'
--- openlp/plugins/images/lib/imageslidecontroller.py	2009-06-29 05:07:32 +0000
+++ openlp/plugins/images/lib/imageslidecontroller.py	2009-07-03 20:32:33 +0000
@@ -22,23 +22,20 @@
 
 from PyQt4 import QtCore, QtGui
 from openlp.core.lib import OpenLPToolbar, translate
-from openlp.core.ui.slidecontroller import BaseToolbar
-
-class ImageToolbar(BaseToolbar):
-
-    def __init__(self, isLive):
+from openlp.core.ui.slidecontroller import MasterToolbar
+
+class ImageToolbar(MasterToolbar):
+
+    def __init__(self, parent,  isLive):
+        MasterToolbar.__init__(self, isLive)
+        self.parent = parent
         self.Toolbar = None
-        self.PreviewListView = QtGui.QListWidget()
-        self.PreviewListData = None
         self.isLive = isLive
         self.defineToolbar()
 
-    def getToolbar(self):
-        return self.Toolbar
-
     def defineToolbar(self):
         # Controller toolbar
-        #self.Toolbar = OpenLPToolbar(self.Controller)
+        self.Toolbar = OpenLPToolbar(self)
         sizeToolbarPolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed,
             QtGui.QSizePolicy.Fixed)
         sizeToolbarPolicy.setHorizontalStretch(0)
@@ -50,11 +47,11 @@
                 u':/slides/slide_first.png',
                 translate(u'SlideController', u'Move to first'),
                 self.onSlideSelectedFirst)
-        self.Toolbar.addToolbarButton(u'Last Slide',
+        self.Toolbar.addToolbarButton(u'Previous Slide',
             u':/slides/slide_previous.png',
             translate(u'SlideController', u'Move to previous'),
             self.onSlideSelectedPrevious)
-        self.Toolbar.addToolbarButton(u'First Slide',
+        self.Toolbar.addToolbarButton(u'Next Slide',
             u':/slides/slide_next.png',
             translate(u'SlideController', u'Move to next'),
             self.onSlideSelectedNext)
@@ -70,34 +67,29 @@
                 self.onBlankScreen)
         self.Toolbar.addSeparator()
         self.Toolbar.addToolbarButton(u'Start Loop',
-            u':/slides/slide_last.png',
+            u':/media/media_time.png',
             translate(u'SlideController', u'Start continuous loop'),
             self.onStartLoop)
         self.Toolbar.addToolbarButton(u'Stop Loop',
-            u':/slides/slide_last.png',
-            translate(u'SlideController', u'Start continuous loop'),
+            u':/media/media_stop.png',
+            translate(u'SlideController', u'Stop continuous loop'),
             self.onStopLoop)
         self.Toolbar.setSizePolicy(sizeToolbarPolicy)
-        self.ControllerLayout.addWidget(self.Toolbar)
 
     def onStartLoop(self):
         """
         Go to the last slide.
         """
-        row = self.PreviewListData.createIndex(
-            self.PreviewListData.rowCount() - 1, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        delay = self.parent.parent.ImageTab.loop_delay
+        self.timer_id =  self.startTimer(delay * 1000)
 
     def onStopLoop(self):
         """
         Go to the last slide.
         """
-        row = self.PreviewListData.createIndex(
-            self.PreviewListData.rowCount() - 1, 0)
-        if row.isValid():
-            self.PreviewListView.selectionModel().setCurrentIndex(row,
-                QtGui.QItemSelectionModel.SelectCurrent)
-            self.onSlideSelected(row)
+        self.killTimer(self.timer_id)
+
+    def timerEvent(self, event):
+        if event.timerId() == self.timer_id:
+            self.onSlideSelectedNext()
+

=== added file 'openlp/plugins/images/lib/imagetab.py'
--- openlp/plugins/images/lib/imagetab.py	1970-01-01 00:00:00 +0000
+++ openlp/plugins/images/lib/imagetab.py	2009-07-03 20:33:41 +0000
@@ -0,0 +1,69 @@
+# -*- coding: utf-8 -*-
+# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4
+"""
+OpenLP - Open Source Lyrics Projection
+Copyright (c) 2008 Raoul Snyman
+Portions copyright (c) 2008-2009 Martin Thompson, Tim Bentley,
+
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+Place, Suite 330, Boston, MA 02111-1307 USA
+"""
+
+from PyQt4 import QtCore, QtGui
+
+from openlp.core.lib import SettingsTab,  str_to_bool,  translate
+
+class ImageTab(SettingsTab):
+    """
+    ImageTab is the Image settings tab in the settings dialog.
+    """
+    def __init__(self):
+        SettingsTab.__init__(self, translate(u'ImageTab', u'Image'), u'Image')
+
+    def setupUi(self):
+        self.setObjectName(u'ImageTab')
+        self.ImageLayout = QtGui.QFormLayout(self)
+        self.ImageLayout.setObjectName(u'ImageLayout')
+        self.ImageModeGroupBox = QtGui.QGroupBox(self)
+        self.ImageModeGroupBox.setObjectName(u'ImageModeGroupBox')
+        self.TimeoutLayout = QtGui.QHBoxLayout(self.ImageModeGroupBox)
+        self.TimeoutLayout.setSpacing(8)
+        self.TimeoutLayout.setMargin(0)
+        self.TimeoutLayout.setObjectName(u'TimeoutLayout')
+        self.TimeoutLabel = QtGui.QLabel(self.ImageModeGroupBox)
+        self.TimeoutLabel.setObjectName(u'TimeoutLabel')
+        self.TimeoutLayout.addWidget(self.TimeoutLabel)
+        self.TimeoutSpinBox = QtGui.QSpinBox(self.ImageModeGroupBox)
+        self.TimeoutSpinBox.setMaximum(180)
+        self.TimeoutSpinBox.setObjectName(u'TimeoutSpinBox')
+        self.TimeoutLayout.addWidget(self.TimeoutSpinBox)
+        self.TimeoutSpacer = QtGui.QSpacerItem(147, 20,
+            QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.TimeoutLayout.addItem(self.TimeoutSpacer)
+
+        self.ImageLayout.setWidget(0, QtGui.QFormLayout.LabelRole, self.ImageModeGroupBox)
+        # Signals and slots
+        QtCore.QObject.connect(self.TimeoutSpinBox,
+            QtCore.SIGNAL(u'valueChanged(int)'), self.onTimeoutSpinBoxChanged)
+
+    def retranslateUi(self):
+        self.TimeoutLabel.setText(translate(u'ImageTab', u'Slide Loop Delay:'))
+
+    def onTimeoutSpinBoxChanged(self):
+        self.loop_delay = self.TimeoutSpinBox.value()
+
+    def load(self):
+        self.loop_delay = int(self.config.get_config(u'loop delay', 5))
+        self.TimeoutSpinBox.setValue(self.loop_delay)
+
+    def save(self):
+        self.config.set_config(u'loop delay', self.loop_delay)

=== modified file 'openlp/plugins/images/lib/mediaitem.py'
--- openlp/plugins/media/lib/mediaitem.py	2009-06-16 18:21:24 +0000
+++ openlp/plugins/media/lib/mediaitem.py	2009-07-04 05:52:30 +0000
@@ -19,6 +19,12 @@
 """
 import logging
 import os
+import tempfile
+try:
+    import gst
+except:
+    log = logging.getLogger(u'MediaMediaItemSetup')
+    log.warning(u'Can\'t generate Videos previews - import gst failed');
 
 from PyQt4 import QtCore, QtGui
 
@@ -26,6 +32,13 @@
 
 from openlp.plugins.media.lib import MediaTab
 from openlp.plugins.media.lib import FileListData
+# from listwithpreviews import ListWithPreviews
+from openlp.core.lib import MediaManagerItem, ServiceItem, translate, BaseListWithDnD, buildIcon
+
+class MediaListView(BaseListWithDnD):
+    def __init__(self, parent=None):
+        self.PluginName = u'Media'
+        BaseListWithDnD.__init__(self, parent)
 
 class MediaMediaItem(MediaManagerItem):
     """
@@ -36,100 +49,98 @@
     log.info(u'Media Media Item loaded')
 
     def __init__(self, parent, icon, title):
+        self.TranslationContext = u'MediaPlugin'
+        self.hasFileIcon = True
+        self.hasNewIcon = False
+        self.hasEditIcon = False
+        self.IconPath = u'images/image'
+        self.PluginTextShort = u'Media'
+        self.ConfigSection = u'images'
+        self.OnNewPrompt = u'Select Media(s)'
+        self.OnNewFileMasks = u'Videos (*.avi *.mpeg *.mpg *.mp4);;Audio (*.ogg *.mp3 *.wma);;All files (*)'
+        # this next is a class, not an instance of a class - it will
+        # be instanced by the base MediaManagerItem
+        self.ListViewWithDnD_class = MediaListView
+        #self.ServiceItemIconName = u':/media/media_image.png'
+        self.PreviewFunction = self.video_get_preview
         MediaManagerItem.__init__(self, parent, icon, title)
 
-    def setupUi(self):
-                # Add a toolbar
-        self.addToolbar()
-        # Create buttons for the toolbar
-        ## New Media Button ##
-        self.addToolbarButton(
-            translate(u'MediaMediaItem',u'New Media'),
-            translate(u'MediaMediaItem',u'Load Media into openlp.org'),
-            ':/videos/video_load.png', self.onMediaNewClick, 'MediaNewItem')
-        ## Delete Media Button ##
-        self.addToolbarButton(
-            translate(u'MediaMediaItem',u'Delete Media'),
-            translate(u'MediaMediaItem',u'Delete the selected Media item'),
-            ':/videos/video_delete.png', self.onMediaDeleteClick, 'MediaDeleteItem')
-        ## Separator Line ##
-        self.addToolbarSeparator()
-        ## Preview Media Button ##
-        self.addToolbarButton(
-            translate(u'MediaMediaItem',u'Preview Media'),
-            translate(u'MediaMediaItem',u'Preview the selected Media item'),
-            ':/system/system_preview.png', self.onMediaPreviewClick, 'MediaPreviewItem')
-        ## Live Media Button ##
-        self.addToolbarButton(
-            translate(u'MediaMediaItem',u'Go Live'),
-            translate(u'MediaMediaItem',u'Send the selected Media item live'),
-            ':/system/system_live.png', self.onMediaLiveClick, 'MediaLiveItem')
-        ## Add Media Button ##
-        self.addToolbarButton(
-            translate(u'MediaMediaItem',u'Add Media To Service'),
-            translate(u'MediaMediaItem',u'Add the selected Media items(s) to the service'),
-            ':/system/system_add.png',self.onMediaAddClick, 'MediaAddItem')
-        ## Add the Medialist widget ##
-
-        self.MediaListView = QtGui.QListView()
-        self.MediaListView.setAlternatingRowColors(True)
-        self.MediaListData = FileListData()
-        self.MediaListView.setModel(self.MediaListData)
-
-        self.PageLayout.addWidget(self.MediaListView)
-
-        #define and add the context menu
-        self.MediaListView.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
-
-        self.MediaListView.addAction(self.contextMenuAction(
-            self.MediaListView, ':/system/system_preview.png',
-            translate(u'MediaMediaItem',u'&Preview Media'), self.onMediaPreviewClick))
-        self.MediaListView.addAction(self.contextMenuAction(
-            self.MediaListView, ':/system/system_live.png',
-            translate(u'MediaMediaItem',u'&Show Live'), self.onMediaLiveClick))
-        self.MediaListView.addAction(self.contextMenuAction(
-            self.MediaListView, ':/system/system_add.png',
-            translate(u'MediaMediaItem',u'&Add to Service'), self.onMediaAddClick))
-
-    def initialise(self):
-        list = self.parent.config.load_list(u'Media')
-        self.loadMediaList(list)
-
-    def onMediaNewClick(self):
-        files = QtGui.QFileDialog.getOpenFileNames(None,
-            translate(u'MediaMediaItem', u'Select Media(s) items'),
-            self.parent.config.get_last_dir(),
-            u'Videos (*.avi *.mpeg);;Audio (*.mp3 *.ogg *.wma);;All files (*)')
-        if len(files) > 0:
-            self.loadMediaList(files)
-            dir, filename = os.path.split(unicode(files[0]))
-            self.parent.config.set_last_dir(dir)
-            self.parent.config.set_list(u'media', self.MediaListData.getFileList())
-
-    def getFileList(self):
-        filelist = [item[0] for item in self.MediaListView];
-        return filelist
-
-    def loadMediaList(self, list):
-        for files in list:
-            self.MediaListData.addRow(files)
-
-    def onMediaDeleteClick(self):
-        indexes = self.MediaListView.selectedIndexes()
+    def video_get_preview(self, filename):
+        """Gets a preview of the first frame of a video file using
+        GSTREAMER (non-portable??? - Can't figure out how to do with
+        Phonon - returns a QImage"""
+        try:
+            # Define your pipeline, just as you would at the command prompt.
+            # This is much easier than trying to create and link each gstreamer element in Python.
+            # This is great for pipelines that end with a filesink (i.e. there is no audible or visual output)
+            log.info ("Video preview %s"%( filename))
+            outfile=tempfile.NamedTemporaryFile(suffix='.png')
+            cmd=u'filesrc location="%s" ! decodebin ! ffmpegcolorspace ! pngenc ! filesink location="%s"'% (filename, outfile.name)
+            pipe = gst.parse_launch(cmd)
+            # Get a reference to the pipeline's bus
+            bus = pipe.get_bus()
+
+            # Set the pipeline's state to PLAYING
+            pipe.set_state(gst.STATE_PLAYING)
+
+            # Listen to the pipeline's bus indefinitely until we receive a EOS (end of stream) message.
+            # This is a super important step, or the pipeline might not work as expected.  For example,
+            # in my example pipeline above, the pngenc will not export an actual image unless you have
+            # this line of code.  It just exports a 0 byte png file.  So... don't forget this step.
+            bus.poll(gst.MESSAGE_EOS, -1)
+            img = QtGui.QImage(outfile.name)
+            outfile.close()
+#             os.unlink(outfile.name)
+            pipe.set_state(gst.STATE_NULL)
+            return img
+        except:
+            log.info("Can't generate video preview for some reason");
+            import sys
+            print sys.exc_info()
+            return None
+
+    def generateSlideData(self, service_item):
+        indexes = self.ListView.selectedIndexes()
+        service_item.title = u'Media'
         for index in indexes:
-            current_row = int(index.row())
-            self.MediaListData.removeRow(current_row)
-        self.parent.config.set_list(u'media', self.MediaListData.getFileList())
+            filename = self.ListData.getFilename(index)
+            frame = QtGui.QImage(unicode(filename))
+            (path, name) = os.path.split(filename)
+            service_item.add_from_image(path,  name, frame)
 
-    def onMediaPreviewClick(self):
+    def onPreviewClick(self):
         log.debug(u'Media Preview Button pressed')
-        items = self.MediaListView.selectedIndexes()
+        items = self.ListView.selectedIndexes()
         for item in items:
-            text = self.MediaListData.getValue(item)
+            text = self.ListData.getValue(item)
             print text
 
     def onMediaLiveClick(self):
+        log.debug(u'Media Live Button pressed')
         pass
 
-    def onMediaAddClick(self):
-        pass
\ No newline at end of file
+    def initialise(self):
+        self.ListView.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
+        self.ListView.setIconSize(QtCore.QSize(88,50))
+        self.loadList(self.parent.config.load_list(self.ConfigSection))
+
+    def onDeleteClick(self):
+        item = self.ListView.currentItem()
+        if item is not None:
+            item_id = (item.data(QtCore.Qt.UserRole)).toInt()[0]
+            row = self.ListView.row(item)
+            self.ListView.takeItem(row)
+            self.parent.config.set_list(self.ConfigSection, self.ListData.getFileList())
+
+    def loadList(self, list):
+        for file in list:
+            (path, filename) = os.path.split(unicode(file))
+            item_name = QtGui.QListWidgetItem(filename)
+            img = self.video_get_preview(file)
+            #item_name.setIcon(buildIcon(file))
+            item_name.setData(QtCore.Qt.UserRole, QtCore.QVariant(file))
+            self.ListView.addItem(item_name)
+
+#     def onMediaAddClick(self):
+#         log.debug(u'Media Add Button pressed')
+#         pass

=== modified file 'openlp/plugins/media/mediaplugin.py'
--- openlp/plugins/media/mediaplugin.py	2009-06-26 17:51:43 +0000
+++ openlp/plugins/media/mediaplugin.py	2009-07-04 05:52:30 +0000
@@ -22,7 +22,6 @@
 
 from openlp.core.lib import Plugin, MediaManagerItem, SettingsTab
 from openlp.plugins.media.lib import MediaTab,MediaMediaItem
-
 class MediaPlugin(Plugin):
 
     def __init__(self, plugin_helpers):

=== removed file 'openlp/plugins/media/video_render.py'
--- openlp/plugins/media/video_render.py	2009-06-22 20:44:35 +0000
+++ openlp/plugins/media/video_render.py	1970-01-01 00:00:00 +0000
@@ -1,70 +0,0 @@
-# -*- coding: utf-8 -*-
-# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4
-"""
-OpenLP - Open Source Lyrics Projection
-Copyright (c) 2008 Raoul Snyman
-Portions copyright (c) 2008 Martin Thompson, Tim Bentley,
-
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation; version 2 of the License.
-
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place, Suite 330, Boston, MA 02111-1307 USA
-"""
-import os
-from PyQt4 import QtCore, QtGui
-
-# xxx this needs a try, except once we've decided what to do if it fails
-from PyQt4.phonon import Phonon
-
-# from openlp.core.lib import Plugin, MediaManagerItem, SettingsTab
-# from openlp.plugins.media.lib import MediaTab,MediaMediaItem
-
-"""Renders a video to some surface or other """
-
-class w(QtGui.QMainWindow):
-    def __init__(self, parent=None):
-        super(QtGui.QMainWindow, self).__init__(parent)
-        self.resize(640,480)
-        self.setWindowTitle(u'simple media player')
-        self.show()
-
-if __name__==u'__main__':
-    app = QtGui.QApplication([])
-#     widget = QtGui.QWidget()
-#     widget.resize(320, 240)
-#     widget.setWindowTitle(u'simple')
-#     widget.show()
-#     QCore.QCoreApplication.setApplicationName(u'OpenLP')
-    mainwindow=w()
-    widget=QtGui.QWidget(mainwindow)
-    mainwindow.setCentralWidget(widget)
-    widget.setLayout(QtGui.QVBoxLayout(widget))
-#     videofile=u'r-128.rm'
-    videofile=u'/extra_space/Download/coa360download56Kbps240x160.mpg'
-    source=Phonon.MediaSource(videofile)
-
-    media=Phonon.MediaObject(widget)
-    media.setCurrentSource(source)
-
-    video=Phonon.VideoWidget(widget)
-    audio=Phonon.AudioOutput(Phonon.MusicCategory)
-#     controller=Phonon.MediaController(media)
-    Phonon.createPath(media, video);
-    Phonon.createPath(media, audio);
-#     player=Phonon.VideoPlayer(Phonon.VideoCategory, widget)
-    slider=Phonon.SeekSlider(media, mainwindow)
-    widget.layout().addWidget(slider)
-    widget.layout().addWidget(video)
-    slider.show()
-    
-    video.show()
-    media.play()
-    app.exec_()
-

=== modified file 'openlp/plugins/presentations/lib/impresscom.py'
--- openlp/plugins/presentations/lib/impresscom.py	2009-06-26 19:06:28 +0000
+++ openlp/plugins/presentations/lib/impresscom.py	2009-07-02 19:04:50 +0000
@@ -57,7 +57,7 @@
             self.createApp()
 
     def startOpenoffice(self):
-        cmd = u'openoffice.org -nologo -norestore -minimized -impress' + u'"' + u'-accept=socket,host=localhost,port=2002;urp;'+ u'"'
+        cmd = u'openoffice.org -nologo -norestore -invisible -minimized -impress' + u'"' + u'-accept=socket,host=localhost,port=2002;urp;'+ u'"'
         retval = subprocess.Popen(cmd,  shell=True)
         self.oopid = retval.pid
 

=== modified file 'openlp/plugins/songs/lib/mediaitem.py'
--- openlp/plugins/songs/lib/mediaitem.py	2009-06-27 19:55:55 +0000
+++ openlp/plugins/songs/lib/mediaitem.py	2009-07-04 05:52:30 +0000
@@ -20,7 +20,7 @@
 import logging
 
 from PyQt4 import QtCore, QtGui
-from openlp.core.lib import MediaManagerItem,  translate,  ServiceItem,  SongXMLParser
+from openlp.core.lib import MediaManagerItem,  translate,  ServiceItem,  SongXMLParser , contextMenuAction, contextMenuSeparator
 
 from openlp.plugins.songs.forms import EditSongForm
 
@@ -138,17 +138,17 @@
            QtCore.SIGNAL(u'doubleClicked(QModelIndex)'), self.onSongPreviewClick)
         #define and add the context menu
         self.ListView.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
-        self.ListView.addAction(self.contextMenuAction(self.ListView,
+        self.ListView.addAction(contextMenuAction(self.ListView,
             ':/songs/song_new.png', translate(u'SongMediaItem', u'&Edit Song'),
             self.onSongEditClick))
-        self.ListView.addAction(self.contextMenuSeparator(self.ListView))
-        self.ListView.addAction(self.contextMenuAction(self.ListView,
+        self.ListView.addAction(contextMenuSeparator(self.ListView))
+        self.ListView.addAction(contextMenuAction(self.ListView,
             ':/system/system_preview.png', translate(u'SongMediaItem', u'&Preview Song'),
             self.onSongPreviewClick))
-        self.ListView.addAction(self.contextMenuAction(self.ListView,
+        self.ListView.addAction(contextMenuAction(self.ListView,
             ':/system/system_live.png', translate(u'SongMediaItem', u'&Show Live'),
             self.onSongLiveClick))
-        self.ListView.addAction(self.contextMenuAction(self.ListView,
+        self.ListView.addAction(contextMenuAction(self.ListView,
             ':/system/system_add.png', translate(u'SongMediaItem', u'&Add to Service'),
             self.onSongAddClick))
 

=== renamed file 'resources/images/media_verse.png' => 'resources/images/media_bible.png'
=== added file 'resources/images/media_stop.png'
Binary files resources/images/media_stop.png	1970-01-01 00:00:00 +0000 and resources/images/media_stop.png	2009-07-03 19:08:21 +0000 differ
=== added file 'resources/images/media_time.png'
Binary files resources/images/media_time.png	1970-01-01 00:00:00 +0000 and resources/images/media_time.png	2009-07-03 19:08:21 +0000 differ
=== modified file 'resources/images/openlp-2.qrc'
--- resources/images/openlp-2.qrc	2009-05-03 15:35:34 +0000
+++ resources/images/openlp-2.qrc	2009-07-03 19:08:21 +0000
@@ -86,8 +86,10 @@
     <file>media_presentation.png</file>
     <file>media_image.png</file>
     <file>media_song.png</file>
-    <file>media_verse.png</file>
+    <file>media_bible.png</file>
     <file>media_video.png</file>
+    <file>media_time.png</file>
+    <file>media_stop.png</file>
   </qresource>
   <qresource prefix="messagebox" >
     <file>messagebox_critical.png</file>


Follow ups
--- openlp/plugins/images/lib/mediaitem.py	2009-06-29 05:13:06 +0000
+++ openlp/plugins/images/lib/mediaitem.py	2009-07-04 05:52:30 +0000
@@ -53,12 +53,12 @@
         # this next is a class, not an instance of a class - it will
         # be instanced by the base MediaManagerItem
         self.ListViewWithDnD_class = ImageListView
+        self.ServiceItemIconName = u':/media/media_image.png'
+
         MediaManagerItem.__init__(self, parent, icon, title)
-        #create and install our own slide controllers
-        #a=c
-#        live_controller = ImageSlideController(self.parent.slideManager.parent, True)
-#        preview_controller = ImageSlideController(self.parent.slideManager.parent)
-#        self.parent.slideManager.add_controllers(u'image', preview_controller, live_controller)
+        #create and install our own slide controller toolbar
+        imageToolbar = ImageToolbar(self, True)
+        parent.live_controller.registerToolbar(self.ConfigSection, imageToolbar)
 
     def initialise(self):
         self.ListView.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)

=== modified file 'openlp/plugins/media/lib/mediaitem.py'